@@ -2,7 +2,6 @@ from __future__ import absolute_import, division, print_function
 
 from distutils.version import LooseVersion
 import pytest
-from pytest import raises as assert_raises
 from numpy.testing import assert_equal
 import dask.array as da
 from dask.array.utils import assert_eq
@@ -25,13 +24,13 @@ def test__parse_gufunc_signature():
                  ([('x',)], [('y',), ()]))
     assert_equal(_parse_gufunc_signature('(),(a,b,c),(d)->(d,e)'),
                  ([(), ('a', 'b', 'c'), ('d',)], ('d', 'e')))
-    with assert_raises(ValueError):
+    with pytest.raises(ValueError):
         _parse_gufunc_signature('(x)(y)->()')
-    with assert_raises(ValueError):
+    with pytest.raises(ValueError):
         _parse_gufunc_signature('(x),(y)->')
-    with assert_raises(ValueError):
+    with pytest.raises(ValueError):
         _parse_gufunc_signature('((x))->(x)')
-    with assert_raises(ValueError):
+    with pytest.raises(ValueError):
         _parse_gufunc_signature('(x)->(x),')
 
 
@@ -118,7 +117,7 @@ def test_apply_gufunc_elemwise_01b():
         return x + y
     a = da.from_array(np.array([1, 2, 3]), chunks=2, name='a')
     b = da.from_array(np.array([1, 2, 3]), chunks=1, name='b')
-    with assert_raises(ValueError):
+    with pytest.raises(ValueError):
         apply_gufunc(add, "(),()->()", a, b, output_dtypes=a.dtype)
 
 
@@ -260,7 +259,7 @@ def test_apply_gufunc_check_same_dimsizes():
     a = da.random.normal(size=(3,), chunks=(2,))
     b = da.random.normal(size=(4,), chunks=(2,))
 
-    with assert_raises(ValueError) as excinfo:
+    with pytest.raises(ValueError) as excinfo:
         apply_gufunc(foo, "(),()->()", a, b, output_dtypes=float, allow_rechunk=True)
     assert "different lengths in arrays" in str(excinfo.value)
 
@@ -269,7 +268,7 @@ def test_apply_gufunc_check_coredim_chunksize():
     def foo(x):
         return np.sum(x, axis=-1)
     a = da.random.normal(size=(8,), chunks=3)
-    with assert_raises(ValueError) as excinfo:
+    with pytest.raises(ValueError) as excinfo:
         da.apply_gufunc(foo, "(i)->()", a, output_dtypes=float, allow_rechunk=False)
     assert "consists of multiple chunks" in str(excinfo.value)
 
@@ -281,6 +280,6 @@ def test_apply_gufunc_check_inhomogeneous_chunksize():
     a = da.random.normal(size=(8,), chunks=((2, 2, 2, 2),))
     b = da.random.normal(size=(8,), chunks=((2, 3, 3),))
 
-    with assert_raises(ValueError) as excinfo:
+    with pytest.raises(ValueError) as excinfo:
         da.apply_gufunc(foo, "(),()->()", a, b, output_dtypes=float, allow_rechunk=False)
     assert "with different chunksize present" in str(excinfo.value)
