@@ -8,7 +8,6 @@ import sys
 import tempfile
 import re
 from errno import ENOENT
-from collections import Iterator
 from contextlib import contextmanager
 from importlib import import_module
 from numbers import Integral
@@ -18,7 +17,8 @@ import uuid
 import warnings
 from weakref import WeakValueDictionary
 
-from .compatibility import get_named_args, getargspec, PY3, unicode, bind_method
+from .compatibility import (get_named_args, getargspec, PY3, unicode,
+                            bind_method, Iterator)
 from .core import get_deps
 from .optimization import key_split    # noqa: F401
 
@@ -892,9 +892,13 @@ def is_arraylike(x):
     >>> is_arraylike('cat')
     False
     """
-    return (# hasattr(x, '__array__') and
-            hasattr(x, 'shape') and x.shape and
-            hasattr(x, 'dtype'))
+    from .base import is_dask_collection
+
+    return (
+        hasattr(x, 'shape') and x.shape and
+        hasattr(x, 'dtype') and
+        not any(is_dask_collection(n) for n in x.shape)
+    )
 
 
 def natural_sort_key(s):
